@@ -24,10 +24,12 @@
 #include "katemainwindow.h"
 #include "kateviewmanager.h"
 #include "katedocmanageradaptor.h"
+#include "katecontainer.h"
 
 #include <KTextEditor/View>
 #include <KTextEditor/SessionConfigInterface>
 #include <KTextEditor/EditorChooser>
+#include <KTextEditor/ContainerInterface>
 
 #include <KParts/Factory>
 
@@ -60,6 +62,12 @@ KateDocManager::KateDocManager (QObject *parent)
   // Constructed the beloved editor ;)
   m_editor = KTextEditor::EditorChooser::editor();
 
+  KTextEditor::ContainerInterface * iface = qobject_cast<KTextEditor::ContainerInterface *>( m_editor );
+  if (iface != NULL) {
+    iface->setContainer( new KateContainer(KateApp::self()) );
+  } else {
+    kDebug()<<"Editor does not support the container interface";
+  }
   // read in editor config
   m_editor->readConfig(KGlobal::config().data());
 
@@ -129,7 +137,7 @@ QVariant KateDocManager::data( const QModelIndex & index, int role ) const
 KTextEditor::Document *KateDocManager::createDoc ()
 {
 
-  kdDebug()<<"createDoc"<<endl;
+  kDebug()<<"createDoc"<<endl;
 
   KTextEditor::Document *doc = (KTextEditor::Document *) m_editor->createDocument(this);
 
@@ -181,7 +189,7 @@ void KateDocManager::slotDocumentNameChanged(KTextEditor::Document* doc)
 
 void KateDocManager::deleteDoc (KTextEditor::Document *doc)
 {
-  kdDebug()<<"deleting document with name:"<<doc->documentName();
+  kDebug()<<"deleting document with name:"<<doc->documentName();
   int remove_row=-1;
   int rows = rowCount();
   m_documentItemMapping.remove(doc);
@@ -208,7 +216,7 @@ void KateDocManager::deleteDoc (KTextEditor::Document *doc)
   emit m_documentManager->documentDeleted (doc);
 
   for (int i=0;i<rowCount();i++) {
-	kdDebug()<<data(index(i,0),Qt::DisplayRole)<<(i==remove_row?"REMOVING":"");
+	kDebug()<<data(index(i,0),Qt::DisplayRole)<<(i==remove_row?"REMOVING":"");
   }
   if (remove_row>-1)
       removeRow(remove_row);
@@ -237,9 +245,12 @@ uint KateDocManager::documents ()
 
 KTextEditor::Document *KateDocManager::findDocument (const KUrl &url) const
 {
+  KUrl u(url);
+  u.cleanPath();
+
   foreach (KTextEditor::Document* it, m_docList)
   {
-    if ( it->url() == url)
+    if ( it->url() == u)
       return it;
   }
 
@@ -254,6 +265,8 @@ bool KateDocManager::isOpen(KUrl url)
 
 KTextEditor::Document *KateDocManager::openUrl (const KUrl& url, const QString &encoding, bool isTempFile)
 {
+  KUrl u(url);
+  u.cleanPath();
   // special handling if still only the first initial doc is there
   if (!documentList().isEmpty() && (documentList().count() == 1) && (!documentList().at(0)->isModified() && documentList().at(0)->url().isEmpty()))
   {
@@ -261,24 +274,24 @@ KTextEditor::Document *KateDocManager::openUrl (const KUrl& url, const QString &
 
     doc->setEncoding(encoding);
 
-    if (!url.isEmpty())
+    if (!u.isEmpty())
     {
       doc->setSuppressOpeningErrorDialogs (m_suppressOpeningErrorDialogs);
 
-      if (!loadMetaInfos(doc, url))
-        doc->openUrl (url);
+      if (!loadMetaInfos(doc, u))
+        doc->openUrl (u);
       else if (! encoding.isEmpty()) // set encoding again if provided, as metainfos sets it.
         doc->setEncoding(encoding);
 
       doc->setSuppressOpeningErrorDialogs (false);
 
-      if ( isTempFile && url.isLocalFile() )
+      if ( isTempFile && u.isLocalFile() )
       {
-        QFileInfo fi( url.path() );
+        QFileInfo fi( u.toLocalFile() );
         if ( fi.exists() )
         {
-          m_tempFiles[ doc] = qMakePair(url, fi.lastModified());
-          kDebug(13001) << "temporary file will be deleted after use unless modified: " << url.prettyUrl();
+          m_tempFiles[ doc] = qMakePair(u, fi.lastModified());
+          kDebug(13001) << "temporary file will be deleted after use unless modified: " << u.prettyUrl();
         }
       }
     }
@@ -293,8 +306,8 @@ KTextEditor::Document *KateDocManager::openUrl (const KUrl& url, const QString &
   KTextEditor::Document *doc = 0;
 
   // always new document if url is empty...
-  if (!url.isEmpty())
-    doc = findDocument (url);
+  if (!u.isEmpty())
+    doc = findDocument (u);
 
   if ( !doc )
   {
@@ -302,12 +315,12 @@ KTextEditor::Document *KateDocManager::openUrl (const KUrl& url, const QString &
 
     doc->setEncoding(encoding);
 
-    if (!url.isEmpty())
+    if (!u.isEmpty())
     {
       doc->setSuppressOpeningErrorDialogs (m_suppressOpeningErrorDialogs);
 
-      if (!loadMetaInfos(doc, url))
-        doc->openUrl (url);
+      if (!loadMetaInfos(doc, u))
+        doc->openUrl (u);
 
       doc->setSuppressOpeningErrorDialogs (false);
     }
@@ -328,7 +341,7 @@ bool KateDocManager::closeDocument(class KTextEditor::Document *doc, bool closeU
 
   if ( closeUrl && m_tempFiles.contains( doc ) )
   {
-    QFileInfo fi( m_tempFiles[ doc ].first.path() );
+    QFileInfo fi( m_tempFiles[ doc ].first.toLocalFile() );
     if ( fi.lastModified() <= m_tempFiles[ doc ].second ||
          KMessageBox::questionYesNo( KateApp::self()->activeMainWindow(),
                                      i18n("The supposedly temporary file %1 has been modified. "
@@ -640,9 +653,9 @@ void KateDocManager::saveMetaInfos(KTextEditor::Document *doc)
 
 bool KateDocManager::computeUrlMD5(const KUrl &url, QByteArray &result)
 {
-  QFile f(url.path());
+  QFile f(url.toLocalFile());
 
-  if (f.open(QIODevice::ReadOnly))
+  if (f.exists() && f.open(QIODevice::ReadOnly))
   {
     KMD5 md5;
 
