@@ -123,6 +123,7 @@ LokalizeMainWindow::~LokalizeMainWindow()
     KConfig config;
     KConfigGroup stateGroup(&config,"State");
     saveProjectState(stateGroup);
+    m_multiEditorAdaptor->deleteLater();
 }
 
 void LokalizeMainWindow::slotSubWindowActivated(QMdiSubWindow* w)
@@ -518,6 +519,9 @@ void LokalizeMainWindow::saveProjectState(KConfigGroup& stateGroup)
     }
     //if (activeSWIndex==-1 && activeSW==m_projectSubWindow)
 
+    if (files.size() == 0 && !m_lastEditorState.isEmpty())
+        dockWidgets.append(m_lastEditorState); // save last state if no editor open
+
     if (stateGroup.isValid())
         stateGroup.writeEntry("Project",Project::instance()->path());
 
@@ -591,6 +595,8 @@ void LokalizeMainWindow::projectLoaded()
         if (!fileOpen(files.at(i), entries.at(i)/*, offsets.at(i)*//*,&activeSW11*/,activeSWIndex==i,mergeFiles.at(i)))
             continue;
     }
+    if (files.size() == 0 && dockWidgets.size() > 0)
+        m_lastEditorState=dockWidgets.first(); // restore last state if no editor open
     if (activeSWIndex==-1)
     {
         m_toBeActiveSubWindow=m_projectSubWindow;
@@ -800,9 +806,36 @@ QString LokalizeMainWindow::dbusName(){return QString("org.kde.lokalize-%1").arg
 void LokalizeMainWindow::busyCursor(bool busy){busy?QApplication::setOverrideCursor(Qt::WaitCursor):QApplication::restoreOverrideCursor();}
 // void LokalizeMainWindow::processEvents(){QCoreApplication::processEvents();}
 
+
+MultiEditorAdaptor::MultiEditorAdaptor(EditorTab *parent)
+ : EditorAdaptor(parent)
+{
+    setObjectName("MultiEditorAdaptor");
+    connect(parent,SIGNAL(destroyed(QObject*)),this,SLOT(handleParentDestroy(QObject*)));
+}
+
+void MultiEditorAdaptor::setEditorTab(EditorTab* e)
+{
+    if (parent())
+        disconnect(parent(),SIGNAL(destroyed(QObject*)),this,SLOT(handleParentDestroy(QObject*)));
+    if (e)
+        connect(e,SIGNAL(destroyed(QObject*)),this,SLOT(handleParentDestroy(QObject*)));
+    setParent(e);
+    setAutoRelaySignals(false);
+    setAutoRelaySignals(true);
+}
+
+void MultiEditorAdaptor::handleParentDestroy(QObject* p)
+{
+    kWarning()<<"avoiding destroying m_multiEditorAdaptor";
+    setParent(0);
+}
+
+
 //END DBus interface
 
 
 
 #include "lokalizemainwindow.moc"
 #include "lokalizesubwindowbase.moc" //this has to be included somewhere ;)
+#include "multieditoradaptor.moc"
