@@ -1,5 +1,5 @@
 /* ****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
 
   Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
 
@@ -34,10 +34,12 @@
 #include "ui_managedatabases.h"
 #include "ui_dbparams.h"
 #include "dbfilesmodel.h"
-#include "tmwindow.h"
+#include "tmtab.h"
 #include "jobs.h"
+#include "tmscanapi.h"
 #include "project.h"
 
+#include <QTimer>
 #include <kfiledialog.h>
 #include <kdialog.h>
 #include <kdebug.h>
@@ -49,15 +51,16 @@ using namespace TM;
 TMManagerWin::TMManagerWin(QWidget *parent)
  : KMainWindow(parent)
 {
-    QWidget* w=new QWidget(this);
+    setCentralWidget(new QWidget(this));
     Ui_TMManager ui_tmManager;
-    ui_tmManager.setupUi(w);
-    setCentralWidget(w);
+    ui_tmManager.setupUi(centralWidget());
+
     ui_tmManager.list->setModel(DBFilesModel::instance());
+    ui_tmManager.list->setRootIndex(DBFilesModel::instance()->rootIndex());
     m_tmListWidget=ui_tmManager.list;
 
-    connect(ui_tmManager.addData,SIGNAL(clicked(bool)),this,SLOT(addDir()));
-    connect(ui_tmManager.create,SIGNAL(clicked(bool)),this,SLOT(addDB()));
+    connect(ui_tmManager.addData,  SIGNAL(clicked(bool)),this,SLOT(addDir()));
+    connect(ui_tmManager.create,   SIGNAL(clicked(bool)),this,SLOT(addDB()));
     connect(ui_tmManager.importTMX,SIGNAL(clicked(bool)),this,SLOT(importTMX()));
     connect(ui_tmManager.exportTMX,SIGNAL(clicked(bool)),this,SLOT(exportTMX()));
 
@@ -67,7 +70,7 @@ TMManagerWin::TMManagerWin(QWidget *parent)
 
 void TMManagerWin::initLater()
 {
-    connect(m_tmListWidget,SIGNAL(activated(const QModelIndex&)),this,SLOT(slotItemActivated(const QModelIndex&)));
+    connect(m_tmListWidget,SIGNAL(activated(QModelIndex)),this,SLOT(slotItemActivated(QModelIndex)));
 
     QPersistentModelIndex* projectDBIndex=DBFilesModel::instance()->projectDBIndex();
     if (projectDBIndex)
@@ -79,7 +82,10 @@ void TMManagerWin::addDir()
     QString dir=KFileDialog::getExistingDirectory(KUrl("kfiledialog:///tm-food"),this,
                         i18nc("@title:window","Select Directory to be scanned"));
     if (!dir.isEmpty())
-        scanRecursive(dir, DBFilesModel::instance()->data(m_tmListWidget->currentIndex()).toString() );
+    {
+        QList<QUrl> dirs; dirs.append(QUrl(dir));
+        scanRecursive(dirs,DBFilesModel::instance()->data(m_tmListWidget->currentIndex()).toString());
+    }
 
 }
 
@@ -94,15 +100,11 @@ void TMManagerWin::addDB()
     if (dialog.exec()&&!ui_dbParams.name->text().isEmpty())
     {
         OpenDBJob* openDBJob=new OpenDBJob(ui_dbParams.name->text(),this);
-        connect(openDBJob,SIGNAL(failed(ThreadWeaver::Job*)),Project::instance(),SLOT(deleteScanJob(ThreadWeaver::Job*)));
-        connect(openDBJob,SIGNAL(done(ThreadWeaver::Job*)),Project::instance(),SLOT(deleteScanJob(ThreadWeaver::Job*)));
 
         openDBJob->m_setParams=true;
         openDBJob->m_markup=ui_dbParams.markup->text();
         openDBJob->m_accel=ui_dbParams.accel->text();
-        kDebug()<<"!!!!!!!!!!!!"<<openDBJob->m_markup;
-
-        ThreadWeaver::Weaver::instance()->enqueue(openDBJob);
+        DBFilesModel::instance()->openDB(openDBJob);
     }
 }
 
@@ -143,9 +145,7 @@ void TMManagerWin::exportTMX()
     if (!path.isEmpty())
     {
         ExportTmxJob* j=new ExportTmxJob(path,dbName);
-        connect(j,SIGNAL(failed(ThreadWeaver::Job*)),j,SLOT(deleteLater()));
         connect(j,SIGNAL(done(ThreadWeaver::Job*)),j,SLOT(deleteLater()));
-
         ThreadWeaver::Weaver::instance()->enqueue(j);
     }
 }
@@ -153,9 +153,9 @@ void TMManagerWin::exportTMX()
 void TMManagerWin::slotItemActivated(const QModelIndex&)
 {
     //QString dbName=DBFilesModel::instance()->data(m_tmListWidget->currentIndex()).toString();
-    TMWindow* win=new TMWindow;
+/*    TMWindow* win=new TMWindow;
     win->selectDB(m_tmListWidget->currentIndex().row());
-    win->show();
+    win->show();*/
 }
 
 
