@@ -4,12 +4,12 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 #include "classifier.h"
 
-// qt/kde includes
+// kde includes
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -38,21 +38,37 @@
 #include "optionstate.h"
 #include "icon_utils.h"
 
+// qt includes
+#include <QtCore/QPointer>
+
 using namespace Uml;
 
-
+/**
+ * Sets up a Classifier.
+ *
+ * @param name   The name of the Concept.
+ * @param id     The unique id of the Concept.
+ */
 UMLClassifier::UMLClassifier(const QString & name, Uml::IDType id)
-        : UMLPackage(name, id)
+  : UMLPackage(name, id)
 {
     m_BaseType = Uml::ot_Class;  // default value
     m_pClassAssoc = NULL;
     m_isRef = false;
 }
 
+/**
+ * Standard deconstructor.
+ */
 UMLClassifier::~UMLClassifier()
 {
 }
 
+/**
+ * Reimplementation of method from class UMLObject for controlling the
+ * exact type of this classifier: class, interface, or datatype.
+ * @param ot   the base type to set
+ */
 void UMLClassifier::setBaseType(Uml::Object_Type ot)
 {
     m_BaseType = ot;
@@ -83,16 +99,33 @@ void UMLClassifier::setBaseType(Uml::Object_Type ot)
     listView->changeIconOf(this, newIcon);
 }
 
+/**
+ * Returns true if this classifier represents an interface.
+ */
 bool UMLClassifier::isInterface() const
 {
     return (m_BaseType == ot_Interface);
 }
 
+/**
+ * Returns true if this classifier represents a datatype.
+ */
 bool UMLClassifier::isDatatype() const
 {
     return (m_BaseType == ot_Datatype);
 }
 
+/**
+ * Checks whether an operation is valid based on its signature -
+ * An operation is "valid" if the operation's name and parameter list
+ * are unique in the classifier.
+ *
+ * @param name      Name of the operation to check.
+ * @param opParams  The operation's argument list.
+ * @param exemptOp  Pointer to the exempt method (optional.)
+ * @return  NULL if the signature is valid (ok), else return a pointer
+ *          to the existing UMLOperation that causes the conflict.
+ */
 UMLOperation * UMLClassifier::checkOperationSignature(
         const QString& name,
         UMLAttributeList opParams,
@@ -122,7 +155,7 @@ UMLOperation * UMLClassifier::checkOperationSignature(
                 break;
             i++;
         }
-        if ( i == pCount ) { // all parameters matched -> the signature is not unique
+        if ( i == pCount ) { // all parameters matched->the signature is not unique
             return test;
         }
     }
@@ -130,6 +163,14 @@ UMLOperation * UMLClassifier::checkOperationSignature(
     return NULL;
 }
 
+/**
+ * Find an operation of the given name and parameter signature.
+ *
+ * @param name     The name of the operation to find.
+ * @param params   The parameter descriptors of the operation to find.
+ *
+ * @return  The operation found.  Will return 0 if none found.
+ */
 UMLOperation* UMLClassifier::findOperation(const QString& name,
                                            Model_Utils::NameAndType_List params)
 {
@@ -149,7 +190,7 @@ UMLOperation* UMLClassifier::findOperation(const QString& name,
             continue;
         int i = 0;
         for (; i < pCount; ++i) {
-            Model_Utils::NameAndType_ListIt nt(params.at(i));
+            Model_Utils::NameAndType_ListIt nt(params.begin() + i);
             UMLClassifier *c = dynamic_cast<UMLClassifier*>((*nt).m_type);
             UMLClassifier *testType = testParams.at(i)->getType();
             if (c == NULL) {  //template parameter
@@ -164,6 +205,27 @@ UMLOperation* UMLClassifier::findOperation(const QString& name,
     return 0;
 }
 
+/**
+ * Creates an operation in the current document.
+ * The new operation is initialized with name, id, etc.
+ * If a method with the given profile already exists in the classifier,
+ * no new method is created and the existing operation is returned.
+ * If no name is provided, or if the params are NULL, an Operation
+ * Dialog is shown to ask the user for a name and parameters.
+ * The operation's signature is checked for validity within the parent
+ * classifier.
+ *
+ * @param name           The operation name (will be chosen internally if
+ *                       none given.)
+ * @param isExistingOp   Optional pointer to bool. If supplied, the bool is
+ *                       set to true if an existing operation is returned.
+ * @param params         Optional list of parameter names and types.
+ *                       If supplied, new operation parameters are
+ *                       constructed using this list.
+ * @return The new operation, or NULL if the operation could not be
+ *         created because for example, the user canceled the dialog
+ *         or no appropriate name can be found.
+ */
 UMLOperation* UMLClassifier::createOperation(
         const QString &name /*=QString()*/,
         bool *isExistingOp  /*=NULL*/,
@@ -196,9 +258,10 @@ UMLOperation* UMLClassifier::createOperation(
         if (nameNotSet)
             op->setName( uniqChildName(Uml::ot_Operation) );
         while (true) {
-            UMLOperationDialog operationDialogue(0, op);
-            if( operationDialogue.exec() != KDialog::Accepted ) {
+            QPointer<UMLOperationDialog> operationDialog = new UMLOperationDialog(0, op);
+            if( operationDialog->exec() != KDialog::Accepted ) {
                 delete op;
+                delete operationDialog;
                 return NULL;
             } else if (checkOperationSignature(op->getName(), op->getParmList())) {
                 KMessageBox::information(0,
@@ -206,6 +269,7 @@ UMLOperation* UMLClassifier::createOperation(
             } else {
                 break;
             }
+            delete operationDialog;
         }
     }
 
@@ -220,8 +284,17 @@ UMLOperation* UMLClassifier::createOperation(
     return op;
 }
 
+/**
+ * Appends an operation to the classifier.
+ * This function is mainly intended for the clipboard.
+ *
+ * @param op         Pointer to the UMLOperation to add.
+ * @param position   Inserted at the given position.
+ * @return           True if the operation was added successfully.
+ */
 bool UMLClassifier::addOperation(UMLOperation* op, int position )
 {
+    Q_ASSERT(op);
     if (m_List.indexOf(op) != -1) {
         uDebug() << "findRef(" << op->getName() << ") finds op (bad)";
         return false;
@@ -250,17 +323,35 @@ bool UMLClassifier::addOperation(UMLOperation* op, int position )
     return true;
 }
 
+/**
+ * Appends an operation to the classifier.
+ * @see bool addOperation(UMLOperation* Op, int position = -1)
+ * This function is mainly intended for the clipboard.
+ *
+ * @param op    Pointer to the UMLOperation to add.
+ * @param log   Pointer to the IDChangeLog.
+ * @return      True if the operation was added successfully.
+ */
 bool UMLClassifier::addOperation(UMLOperation* op, IDChangeLog* log)
 {
     if ( addOperation(op, -1) ) {
         return true;
     }
     else if (log) {
-        log->removeChangeByNewID( op -> getID() );
+        log->removeChangeByNewID( op->getID() );
     }
     return false;
 }
 
+/**
+ * Remove an operation from the Classifier.
+ * The operation is not deleted so the caller is responsible for what
+ * happens to it after this.
+ *
+ * @param op   The operation to remove.
+ * @return     Count of the remaining operations after removal, or
+ *             -1 if the given operation was not found.
+ */
 int UMLClassifier::removeOperation(UMLOperation *op)
 {
     if (op == NULL) {
@@ -279,6 +370,11 @@ int UMLClassifier::removeOperation(UMLOperation *op)
     return m_List.count();
 }
 
+/**
+ * Create and add a just created template.
+ * @param currentName   the name of the template
+ * @return              the template or NULL
+ */
 UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString()*/)
 {
     QString name = currentName;
@@ -290,9 +386,9 @@ UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString(
 
     int button = KDialog::Accepted;
 
-    while (button==KDialog::Accepted && !goodName) {
-        UMLTemplateDialog templateDialogue(0, newTemplate);
-        button = templateDialogue.exec();
+    while (button == KDialog::Accepted && !goodName) {
+        QPointer<UMLTemplateDialog> templateDialog = new UMLTemplateDialog(0, newTemplate);
+        button = templateDialog->exec();
         name = newTemplate->getName();
 
         if (name.length() == 0) {
@@ -304,6 +400,7 @@ UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString(
         else {
             goodName = true;
         }
+        delete templateDialog;
     }
 
     if (button != KDialog::Accepted) {
@@ -317,16 +414,26 @@ UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString(
     return newTemplate;
 }
 
+/**
+ * Returns the number of attributes for the class.
+ *
+ * @return  The number of attributes for the class.
+ */
 int UMLClassifier::attributes()
 {
     UMLClassifierListItemList atts = getFilteredList(Uml::ot_Attribute);
     return atts.count();
 }
 
+/**
+ * Returns the attributes for the specified scope.
+ * @return   List of true attributes for the class.
+ */
 UMLAttributeList UMLClassifier::getAttributeList() const
 {
     UMLAttributeList attributeList;
     foreach (UMLObject* listItem , m_List ) {
+        uIgnoreZeroPointer(listItem);
         if (listItem->getBaseType() == Uml::ot_Attribute) {
             attributeList.append(static_cast<UMLAttribute*>(listItem));
         }
@@ -334,6 +441,11 @@ UMLAttributeList UMLClassifier::getAttributeList() const
     return attributeList;
 }
 
+/**
+ * Returns the attributes for the specified scope.
+ * @param scope   The scope of the attribute.
+ * @return        List of true attributes for the class.
+ */
 UMLAttributeList UMLClassifier::getAttributeList(Uml::Visibility scope) const
 {
     UMLAttributeList list;
@@ -342,6 +454,7 @@ UMLAttributeList UMLClassifier::getAttributeList(Uml::Visibility scope) const
         UMLAttributeList atl = getAttributeList();
         foreach(UMLAttribute* at, atl )
         {
+            uIgnoreZeroPointer(at);
             if (! at->getStatic())
             {
                 if (scope == Uml::Visibility::Private)
@@ -362,6 +475,12 @@ UMLAttributeList UMLClassifier::getAttributeList(Uml::Visibility scope) const
     return list;
 }
 
+/**
+ * Returns the static attributes for the specified scope.
+ *
+ * @param scope   The scope of the attribute.
+ * @return        List of true attributes for the class.
+ */
 UMLAttributeList UMLClassifier::getAttributeListStatic(Uml::Visibility scope) const
 {
     UMLAttributeList list;
@@ -370,6 +489,7 @@ UMLAttributeList UMLClassifier::getAttributeListStatic(Uml::Visibility scope) co
         UMLAttributeList atl = getAttributeList();
         foreach(UMLAttribute* at, atl )
         {
+            uIgnoreZeroPointer(at);
             if (at->getStatic())
             {
                 if (scope == Uml::Visibility::Private)
@@ -390,11 +510,18 @@ UMLAttributeList UMLClassifier::getAttributeListStatic(Uml::Visibility scope) co
     return list;
 }
 
+/**
+ * Find a list of operations with the given name.
+ *
+ * @param n   The name of the operation to find.
+ * @return    The list of objects found; will be empty if none found.
+ */
 UMLOperationList UMLClassifier::findOperations(const QString &n)
 {
     const bool caseSensitive = UMLApp::app()->activeLanguageIsCaseSensitive();
     UMLOperationList list;
     foreach (UMLObject*  obj, m_List) {
+        uIgnoreZeroPointer(obj);
         if (obj->getBaseType() != Uml::ot_Operation)
             continue;
         UMLOperation *op = static_cast<UMLOperation*>(obj);
@@ -408,6 +535,12 @@ UMLOperationList UMLClassifier::findOperations(const QString &n)
     return list;
 }
 
+/**
+ * Find the child object by the given id.
+ * @param id                  the id of the child object
+ * @param considerAncestors   flag whether the ancestors should be considered during search
+ * @return                    the found child object or NULL
+ */
 UMLObject* UMLClassifier::findChildObjectById(Uml::IDType id, bool considerAncestors /* =false */)
 {
     UMLObject *o = UMLCanvasObject::findChildObjectById(id);
@@ -426,6 +559,12 @@ UMLObject* UMLClassifier::findChildObjectById(Uml::IDType id, bool considerAnces
     return NULL;
 }
 
+/**
+ * Returns a list of concepts which inherit from this concept.
+ *
+ * @param type   The ClassifierType to seek.
+ * @return       List of UMLClassifiers that inherit from us.
+ */
 UMLClassifierList UMLClassifier::findSubClassConcepts (ClassifierType type)
 {
     UMLClassifierList list = getSubClasses();
@@ -434,6 +573,7 @@ UMLClassifierList UMLClassifier::findSubClassConcepts (ClassifierType type)
     UMLClassifierList inheritingConcepts;
     Uml::IDType myID = getID();
     foreach(UMLClassifier *c , list ) {
+        uIgnoreZeroPointer(c);
         if (type == ALL || (!c->isInterface() && type == CLASS)
                 || (c->isInterface() && type == INTERFACE)) {
             inheritingConcepts.append(c);
@@ -441,6 +581,7 @@ UMLClassifierList UMLClassifier::findSubClassConcepts (ClassifierType type)
     }
 
     foreach (UMLAssociation *a , rlist ) {
+        uIgnoreZeroPointer(a);
         if (a->getObjectId(A) != myID)
         {
             UMLObject* obj = a->getObject(A);
@@ -457,6 +598,12 @@ UMLClassifierList UMLClassifier::findSubClassConcepts (ClassifierType type)
     return inheritingConcepts;
 }
 
+/**
+ * Returns a list of concepts which this concept inherits from.
+ *
+ * @param type   The ClassifierType to seek.
+ * @return       List of UMLClassifiers we inherit from.
+ */
 UMLClassifierList UMLClassifier::findSuperClassConcepts (ClassifierType type)
 {
     UMLClassifierList list = getSuperClasses();
@@ -465,6 +612,7 @@ UMLClassifierList UMLClassifier::findSuperClassConcepts (ClassifierType type)
     UMLClassifierList parentConcepts;
     Uml::IDType myID = getID();
     foreach (UMLClassifier *concept , list ) {
+        uIgnoreZeroPointer(concept);
         if (type == ALL || (!concept->isInterface() && type == CLASS)
                 || (concept->isInterface() && type == INTERFACE))
             parentConcepts.append(concept);
@@ -485,6 +633,9 @@ UMLClassifierList UMLClassifier::findSuperClassConcepts (ClassifierType type)
     return parentConcepts;
 }
 
+/**
+ * Overloaded '==' operator.
+ */
 bool UMLClassifier::operator==(const UMLClassifier & rhs )
 {
   /*
@@ -498,7 +649,10 @@ bool UMLClassifier::operator==(const UMLClassifier & rhs )
     return UMLCanvasObject::operator==(rhs);
 }
 
-
+/**
+ * Copy the internal presentation of this object into the new
+ * object.
+ */
 void UMLClassifier::copyInto(UMLObject *lhs) const
 {
     UMLClassifier *target = static_cast<UMLClassifier*>(lhs);
@@ -508,6 +662,9 @@ void UMLClassifier::copyInto(UMLObject *lhs) const
     m_List.copyInto(&(target->m_List));
 }
 
+/**
+ * Make a clone of this object.
+ */
 UMLObject* UMLClassifier::clone() const
 {
     UMLClassifier *clone = new UMLClassifier();
@@ -515,11 +672,20 @@ UMLObject* UMLClassifier::clone() const
     return clone;
 }
 
+/**
+ * Needs to be called after all UML objects are loaded from file.
+ * Calls the parent resolveRef(), and calls resolveRef() on all
+ * UMLClassifierListItems.
+ * Overrides the method from UMLObject.
+ *
+ * @return  true for success.
+ */
 bool UMLClassifier::resolveRef()
 {
     bool success = UMLPackage::resolveRef();
     // Using reentrant iteration is a bare necessity here:
     foreach (UMLObject* obj, m_List ) {
+        uIgnoreZeroPointer(obj);
         /**** For reference, here is the non-reentrant iteration scheme -
               DO NOT USE THIS !
         for (UMLObject *obj = m_List.first(); obj; obj = m_List.next())
@@ -545,6 +711,9 @@ bool UMLClassifier::resolveRef()
     return success;
 }
 
+/**
+ * Reimplemented from UMLObject.
+ */
 bool UMLClassifier::acceptAssociationType(Uml::Association_Type type)
 {
     switch(type)
@@ -566,6 +735,15 @@ bool UMLClassifier::acceptAssociationType(Uml::Association_Type type)
     return false; //shutup compiler warning
 }
 
+/**
+ * Creates an attribute for the class.
+ *
+ * @param name  An optional name, used by when creating through UMLListView
+ * @param type  An optional type, used by when creating through UMLListView
+ * @param vis   An optional visibility, used by when creating through UMLListView
+ * @param init  An optional initial value, used by when creating through UMLListView
+ * @return      The UMLAttribute created
+ */
 UMLAttribute* UMLClassifier::createAttribute(const QString &name,
                                              UMLObject *type,
                                              Uml::Visibility vis,
@@ -586,8 +764,8 @@ UMLAttribute* UMLClassifier::createAttribute(const QString &name,
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
     while (button == KDialog::Accepted && !goodName && name.isNull()) {
-        UMLAttributeDialog attributeDialogue(0, newAttribute);
-        button = attributeDialogue.exec();
+        QPointer<UMLAttributeDialog> attributeDialog = new UMLAttributeDialog(0, newAttribute);
+        button = attributeDialog->exec();
         QString name = newAttribute->getName();
 
         if(name.length() == 0) {
@@ -597,6 +775,7 @@ UMLAttribute* UMLClassifier::createAttribute(const QString &name,
         } else {
             goodName = true;
         }
+        delete attributeDialog;
     }
 
     if (button != KDialog::Accepted) {
@@ -611,9 +790,18 @@ UMLAttribute* UMLClassifier::createAttribute(const QString &name,
     return newAttribute;
 }
 
+/**
+ * Creates and adds an attribute for the class.
+ *
+ * @param name  an optional name, used by when creating through UMLListView
+ * @param id    an optional id
+ * @return      the UMLAttribute created and added
+ */
+
 UMLAttribute* UMLClassifier::addAttribute(const QString &name, Uml::IDType id /* = Uml::id_None */)
 {
     foreach (UMLObject* obj, m_List ) {
+        uIgnoreZeroPointer(obj);
         if (obj->getBaseType() == Uml::ot_Attribute && obj->getName() == name)
             return static_cast<UMLAttribute*>(obj);
     }
@@ -626,6 +814,15 @@ UMLAttribute* UMLClassifier::addAttribute(const QString &name, Uml::IDType id /*
     return a;
 }
 
+/**
+ * Adds an already created attribute.
+ * The attribute object must not belong to any other concept.
+ *
+ * @param name    the name of the attribute
+ * @param type    the type of the attribute 
+ * @param scope   the visibility of the attribute
+ * @return        the just created and added attribute
+ */
 UMLAttribute* UMLClassifier::addAttribute(const QString &name, UMLObject *type, Uml::Visibility scope)
 {
     UMLAttribute *a = new UMLAttribute(this);
@@ -642,9 +839,22 @@ UMLAttribute* UMLClassifier::addAttribute(const QString &name, UMLObject *type,
     return a;
 }
 
+/**
+ * Adds an already created attribute.
+ * The attribute object must not belong to any other concept.
+ *
+ * @param att        Pointer to the UMLAttribute.
+ * @param log        Pointer to the IDChangeLog (optional.)
+ * @param position   Position index for the insertion (optional.)
+ *                   If the position is omitted, or if it is
+ *                   negative or too large, the attribute is added
+ *                   to the end of the list.
+ * @return           True if the attribute was successfully added.
+ */
 bool UMLClassifier::addAttribute(UMLAttribute* att, IDChangeLog* log /* = 0 */,
                                  int position /* = -1 */)
 {
+    Q_ASSERT(att);
     if (findChildObject(att->getName()) == NULL) {
         att->setParent(this);
         if (position >= 0 && position < (int)m_List.count()) {
@@ -664,6 +874,13 @@ bool UMLClassifier::addAttribute(UMLAttribute* att, IDChangeLog* log /* = 0 */,
     return false;
 }
 
+/**
+ * Removes an attribute from the class.
+ *
+ * @param att   The attribute to remove.
+ * @return      Count of the remaining attributes after removal.
+ *              Returns -1 if the given attribute was not found.
+ */
 int UMLClassifier::removeAttribute(UMLAttribute* att)
 {
     if (!m_List.removeAll(att)) {
@@ -679,20 +896,33 @@ int UMLClassifier::removeAttribute(UMLAttribute* att)
     return m_List.count();
 }
 
+/**
+ * Sets the UMLAssociation for which this class shall act as an
+ * association class.
+ */
 void UMLClassifier::setClassAssoc(UMLAssociation *assoc)
 {
     m_pClassAssoc = assoc;
 }
 
+/**
+ * Returns the UMLAssociation for which this class acts as an
+ * association class. Returns NULL if this class does not act
+ * as an association class.
+ */
 UMLAssociation *UMLClassifier::getClassAssoc() const
 {
     return m_pClassAssoc;
 }
 
+/**
+ * Return true if this classifier has abstract operations.
+ */
 bool UMLClassifier::hasAbstractOps ()
 {
     UMLOperationList opl( getOpList() );
     foreach(UMLOperation *op , opl ) {
+        uIgnoreZeroPointer(op);
         if (op->getAbstract()) {
             return true;
         }
@@ -700,15 +930,27 @@ bool UMLClassifier::hasAbstractOps ()
     return false;
 }
 
+/**
+ * Counts the number of operations in the Classifier.
+ *
+ * @return   The number of operations for the Classifier.
+ */
 int UMLClassifier::operations()
 {
     return getOpList().count();
 }
 
+/**
+ * Return a list of operations for the Classifier.
+ *
+ * @param includeInherited   Includes operations from superclasses.
+ * @return   The list of operations for the Classifier.
+ */
 UMLOperationList UMLClassifier::getOpList(bool includeInherited)
 {
     UMLOperationList ops;
     foreach (UMLObject* li, m_List) {
+        uIgnoreZeroPointer(li);
         if (li->getBaseType() == ot_Operation) {
             ops.append(static_cast<UMLOperation*>(li));
         }
@@ -740,11 +982,19 @@ UMLOperationList UMLClassifier::getOpList(bool includeInherited)
     return ops;
 }
 
+/**
+ * Returns the entries in m_List that are of the requested type.
+ * If the requested type is Uml::ot_UMLObject then all entries
+ * are returned.
+ * @param ot   the requested object type
+ * @return     The list of true operations for the Concept.
+ */
 UMLClassifierListItemList UMLClassifier::getFilteredList(Uml::Object_Type ot) const
 {
     UMLClassifierListItemList resultList;
     foreach (UMLObject* o, m_List) {
-        if (o->getBaseType() == Uml::ot_Association) {
+        uIgnoreZeroPointer(o);
+        if (!o || o->getBaseType() == Uml::ot_Association) {
             continue;
         }
         UMLClassifierListItem *listItem = static_cast<UMLClassifierListItem*>(o);
@@ -755,6 +1005,14 @@ UMLClassifierListItemList UMLClassifier::getFilteredList(Uml::Object_Type ot) co
     return resultList;
 }
 
+/**
+ * Adds an already created template.
+ * The template object must not belong to any other concept.
+ *
+ * @param name   the name of the template
+ * @param id     the id of the template
+ * @return       the added template
+ */
 UMLTemplate* UMLClassifier::addTemplate(const QString &name, Uml::IDType id)
 {
     UMLTemplate *templt = findTemplate(name);
@@ -769,6 +1027,14 @@ UMLTemplate* UMLClassifier::addTemplate(const QString &name, Uml::IDType id)
     return templt;
 }
 
+/**
+ * Adds an already created template.
+ * The template object must not belong to any other concept.
+ *
+ * @param newTemplate   Pointer to the UMLTemplate object to add.
+ * @param log           Pointer to the IDChangeLog.
+ * @return              True if the template was successfully added.
+ */
 bool UMLClassifier::addTemplate(UMLTemplate* newTemplate, IDChangeLog* log /* = 0*/)
 {
     QString name = newTemplate->getName();
@@ -787,6 +1053,16 @@ bool UMLClassifier::addTemplate(UMLTemplate* newTemplate, IDChangeLog* log /* =
     return false;
 }
 
+/**
+ * Adds an template to the class.
+ * The template object must not belong to any other class.
+ * TODO: If the param IDChangeLog from the method above is not being used,
+ * give position a default value of -1 and the method can replace the above one.
+ * @param templt     Pointer to the UMLTemplate to add.
+ * @param position   The position of the template in the list.
+ *                   A value of -1 will add the template at the end.
+ * @return  True if the template was successfully added.
+ */
 bool UMLClassifier::addTemplate(UMLTemplate* templt, int position)
 {
     QString name = templt->getName();
@@ -807,6 +1083,13 @@ bool UMLClassifier::addTemplate(UMLTemplate* templt, int position)
     return false;
 }
 
+/**
+ * Removes a template from the class.
+ *
+ * @param umltemplate   The template to remove.
+ * @return  Count of the remaining templates after removal.
+ *          Returns -1 if the given template was not found.
+ */
 int UMLClassifier::removeTemplate(UMLTemplate* umltemplate)
 {
     if ( !m_List.removeAll(umltemplate) ) {
@@ -819,7 +1102,11 @@ int UMLClassifier::removeTemplate(UMLTemplate* umltemplate)
     return m_List.count();
 }
 
-
+/**
+ * Seeks the template parameter of the given name.
+ * @param name   the template name
+ * @return       the found template or 0
+ */
 UMLTemplate *UMLClassifier::findTemplate(const QString& name)
 {
     UMLTemplateList templParams = getTemplateList();
@@ -828,19 +1115,32 @@ UMLTemplate *UMLClassifier::findTemplate(const QString& name)
             return templt;
         }
     }
-    return NULL;
+    return 0;
 }
 
+/**
+ * Returns the number of templates for the class.
+ *
+ * @return  The number of templates for the class.
+ */
 int UMLClassifier::templates()
 {
     UMLClassifierListItemList tempList = getFilteredList(Uml::ot_Template);
     return tempList.count();
 }
 
+/**
+ * Returns the templates.
+ * Same as UMLClassifier::getFilteredList(ot_Template) but
+ * return type is a true UMLTemplateList.
+ *
+ * @return  Pointer to the list of true templates for the class.
+ */
 UMLTemplateList UMLClassifier::getTemplateList() const
 {
     UMLTemplateList templateList;
     foreach (UMLObject* listItem, m_List) {
+        uIgnoreZeroPointer(listItem);
         if (listItem->getBaseType() == Uml::ot_Template) {
             templateList.append(static_cast<UMLTemplate*>(listItem));
         }
@@ -848,10 +1148,19 @@ UMLTemplateList UMLClassifier::getTemplateList() const
     return templateList;
 }
 
+/**
+ * Take and return a subordinate item from this classifier.
+ * Ownership of the item is passed to the caller.
+ *
+ * @param item   Subordinate item to take.
+ * @return       Index in m_List of the item taken.
+ *               Return -1 if the item is not found in m_List.
+ */
 int UMLClassifier::takeItem(UMLClassifierListItem *item)
 {
     QString buf;
     foreach (UMLObject* currentAtt, m_List ) {
+        uIgnoreZeroPointer(currentAtt);
         QString txt = currentAtt->getName();
         if (txt.isEmpty()) {
            txt = "Type-" + QString::number((int) currentAtt->getBaseType());
@@ -920,26 +1229,46 @@ int UMLClassifier::takeItem(UMLClassifierListItem *item)
     return index;
 }
 
+/**
+ * Set the origin type (in case of e.g. typedef)
+ * @param origType   the origin type to set
+ */
 void UMLClassifier::setOriginType(UMLClassifier *origType)
 {
     m_pSecondary = origType;
 }
 
+/**
+ * Get the origin type (in case of e.g. typedef)
+ * @return   the origin type
+ */
 UMLClassifier * UMLClassifier::originType() const
 {
     return static_cast<UMLClassifier*>(m_pSecondary);
 }
 
+/**
+ * Set the m_isRef flag (true when dealing with a pointer type)
+ * @param isRef   the flag to set
+ */
 void UMLClassifier::setIsReference(bool isRef)
 {
     m_isRef = isRef;
 }
 
+/**
+ * Get the m_isRef flag.
+ * @return   true if is reference, otherwise false
+ */
 bool UMLClassifier::isReference() const
 {
     return m_isRef;
 }
 
+/**
+ * Return true if this classifier has associations.
+ * @return   true if classifier has associations
+ */
 bool UMLClassifier::hasAssociations()
 {
     return getSpecificAssocs(Uml::at_Association).count() > 0
@@ -948,6 +1277,9 @@ bool UMLClassifier::hasAssociations()
             || getUniAssociationToBeImplemented().count() > 0;
 }
 
+/**
+ * Return true if this classifier has attributes.
+ */
 bool UMLClassifier::hasAttributes()
 {
     return getAttributeList(Uml::Visibility::Public).count() > 0
@@ -958,6 +1290,9 @@ bool UMLClassifier::hasAttributes()
             || getAttributeListStatic(Uml::Visibility::Private).count() > 0;
 }
 
+/**
+ * Return true if this classifier has static attributes.
+ */
 bool UMLClassifier::hasStaticAttributes()
 {
     return getAttributeListStatic(Uml::Visibility::Public).count() > 0
@@ -965,16 +1300,25 @@ bool UMLClassifier::hasStaticAttributes()
             || getAttributeListStatic(Uml::Visibility::Private).count() > 0;
 }
 
+/**
+ * Return true if this classifier has accessor methods.
+ */
 bool UMLClassifier::hasAccessorMethods()
 {
     return hasAttributes() || hasAssociations();
 }
 
+/**
+ * Return true if this classifier has operation methods.
+ */
 bool UMLClassifier::hasOperationMethods()
 {
     return getOpList().last() ? true : false;
 }
 
+/**
+ * Return true if this classifier has methods.
+ */
 bool UMLClassifier::hasMethods()
 {
     return hasOperationMethods() || hasAccessorMethods();
@@ -983,17 +1327,25 @@ bool UMLClassifier::hasMethods()
 // this is a bit too simplistic..some associations are for
 // SINGLE objects, and WONT be declared as Vectors, so this
 // is a bit overly inclusive (I guess that's better than the other way around)
+
+/**
+ * Return true if this classifier has vector fields.
+ */
 bool UMLClassifier::hasVectorFields()
 {
     return hasAssociations();
 }
 
+/**
+ * Return the list of unidirectional association that should show up in the code
+ */
 UMLAssociationList  UMLClassifier::getUniAssociationToBeImplemented()
 {
     UMLAssociationList associations = getSpecificAssocs(Uml::at_UniAssociation);
     UMLAssociationList uniAssocListToBeImplemented;
 
     foreach (UMLAssociation *a , associations ) {
+        uIgnoreZeroPointer(a);
         if (a->getObjectId(Uml::B) == getID()) {
             continue;  // we need to be at the A side
         }
@@ -1003,6 +1355,7 @@ UMLAssociationList  UMLClassifier::getUniAssociationToBeImplemented()
             bool found = false;
             //make sure that an attribute with the same name doesn't already exist
             foreach (UMLAttribute *at , atl ) {
+                uIgnoreZeroPointer(a);
                 if (at->getName() == roleNameB) {
                     found = true;
                     break;
@@ -1016,6 +1369,10 @@ UMLAssociationList  UMLClassifier::getUniAssociationToBeImplemented()
     return uniAssocListToBeImplemented;
 }
 
+/**
+ * Auxiliary to saveToXMI of inheriting classes:
+ * Saves template parameters to the given QDomElement.
+ */
 void UMLClassifier::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 {
     QString tag;
@@ -1070,13 +1427,13 @@ void UMLClassifier::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
     QDomElement featureElement = qDoc.createElement( "UML:Classifier.feature" );
     UMLClassifierListItemList attList = getFilteredList(Uml::ot_Attribute);
     foreach (UMLClassifierListItem *pAtt , attList ) {
-        pAtt -> saveToXMI( qDoc, featureElement );
+        pAtt->saveToXMI( qDoc, featureElement );
     }
 
     // save operations
     UMLOperationList opList = getOpList();
     foreach (UMLOperation *pOp , opList ) {
-        pOp -> saveToXMI( qDoc, featureElement );
+        pOp->saveToXMI( qDoc, featureElement );
     }
     if (featureElement.hasChildNodes()) {
         classifierElement.appendChild( featureElement );
@@ -1093,6 +1450,13 @@ void UMLClassifier::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
     qElement.appendChild( classifierElement );
 }
 
+/**
+ * Create a new ClassifierListObject (attribute, operation, template)
+ * according to the given XMI tag.
+ * Returns NULL if the string given does not contain one of the tags
+ * <UML:Attribute>, <UML:Operation>, or <UML:TemplateParameter>.
+ * Used by the clipboard for paste operation.
+ */
 UMLClassifierListItem* UMLClassifier::makeChildObject(const QString& xmiTag)
 {
     UMLClassifierListItem* pObject = NULL;
@@ -1108,6 +1472,13 @@ UMLClassifierListItem* UMLClassifier::makeChildObject(const QString& xmiTag)
     return pObject;
 }
 
+/**
+ * Auxiliary to loadFromXMI:
+ * The loading of operations is implemented here.
+ * Calls loadSpecialized() for any other tag.
+ * Child classes can override the loadSpecialized method
+ * to load its additional tags.
+ */
 bool UMLClassifier::load(QDomElement& element)
 {
     UMLClassifierListItem *child = NULL;
