@@ -1,33 +1,34 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "activitydialog.h"
 
-//qt includes
-#include <QtGui/QFrame>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QGridLayout>
-#include <QtGui/QCheckBox>
-#include <QtGui/QRadioButton>
-//kde includes
-#include <kvbox.h>
-#include <klocale.h>
-
 //local includes
 #include "umlview.h"
 #include "activitywidget.h"
 #include "dialog_utils.h"
 #include "icon_utils.h"
 
+//kde includes
+#include <kvbox.h>
+#include <klocale.h>
+
+//qt includes
+#include <QtGui/QFrame>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QGridLayout>
+#include <QtGui/QCheckBox>
+#include <QtGui/QGroupBox>
+#include <QtGui/QLabel>
+#include <QtGui/QRadioButton>
 
 ActivityDialog::ActivityDialog( UMLView * pView, ActivityWidget * pWidget )
         : KPageDialog(pView)
@@ -46,6 +47,9 @@ ActivityDialog::ActivityDialog( UMLView * pView, ActivityWidget * pWidget )
     connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
 }
 
+/**
+ *   Entered when OK button pressed.
+ */
 void ActivityDialog::slotOk()
 {
     applyPage( pageItemColor );
@@ -54,6 +58,9 @@ void ActivityDialog::slotOk()
     accept();
 }
 
+/**
+ *   Entered when Apply button pressed.
+ */
 void ActivityDialog::slotApply()
 {
     applyPage(currentPage());
@@ -65,13 +72,11 @@ void ActivityDialog::slotShowActivityParameter()
     m_GenPageWidgets.preLE->show();
     m_GenPageWidgets.postL->show();
     m_GenPageWidgets.postLE->show();
-    if (m_pActivityWidget->getPostText() != NULL)
-    {
-        m_GenPageWidgets.postLE->setText(m_pActivityWidget->getPostText());
+    if(!m_pActivityWidget->postconditionText().isEmpty()) {
+        m_GenPageWidgets.postLE->setText(m_pActivityWidget->postconditionText());
     }
-    if (m_pActivityWidget->getPreText() != NULL)
-    {
-        m_GenPageWidgets.preLE->setText(m_pActivityWidget->getPreText());
+    if (!m_pActivityWidget->preconditionText().isEmpty()) {
+        m_GenPageWidgets.preLE->setText(m_pActivityWidget->preconditionText());
     }
 }
 
@@ -83,22 +88,28 @@ void ActivityDialog::slotHideActivityParameter()
     m_GenPageWidgets.postLE->hide();
 }
 
-void ActivityDialog::setupPages() {
+/**
+ *   Sets up the pages of the dialog.
+ */
+void ActivityDialog::setupPages()
+{
     setupGeneralPage();
     setupColorPage();
     setupFontPage();
 }
 
+/**
+ *     Applies changes to the given page.
+ */
 void ActivityDialog::applyPage( KPageWidgetItem *item )
 {
     m_bChangesMade = true;
     if ( item == pageItemGeneral )
     {
-        m_pActivityWidget -> setName( m_GenPageWidgets.nameLE -> text() );
-        m_pActivityWidget -> setDoc( m_GenPageWidgets.docMLE -> text() );
-        m_pActivityWidget -> setPreText( m_GenPageWidgets.preLE -> text() );
-        m_pActivityWidget -> setPostText( m_GenPageWidgets.postLE -> text() );
-
+        m_pActivityWidget->setName( m_GenPageWidgets.nameLE->text() );
+        m_pActivityWidget->setDocumentation( m_GenPageWidgets.docTE->toPlainText() );
+        m_pActivityWidget->setPreconditionText( m_GenPageWidgets.preLE->text() );
+        m_pActivityWidget->setPostconditionText( m_GenPageWidgets.postLE->text() );
 
         ActivityWidget::ActivityType newType = ActivityWidget::Normal;
         if ( m_GenPageWidgets.InvokRB->isChecked() )
@@ -110,19 +121,21 @@ void ActivityDialog::applyPage( KPageWidgetItem *item )
     }
     else if ( item == pageItemFont )
     {
-        m_pActivityWidget -> setFont( m_pChooser -> font() );
+        m_pActivityWidget->setFont( m_pChooser->font() );
     }
     else if ( item == pageItemColor )
     {
-        m_pColorPage -> updateUMLWidget();
+        m_pColorPage->updateUMLWidget();
     }
 }
 
-
+/**
+ *   Sets up the general page of the dialog.
+ */
 void ActivityDialog::setupGeneralPage()
 {
     QString types[ ] = { i18n("Initial activity"), i18n("Activity"), i18n("End activity"), i18n( "Branch/Merge"), i18n( "Fork/Join" ) };
-    ActivityWidget::ActivityType type = m_pActivityWidget -> getActivityType();
+    ActivityWidget::ActivityType type = m_pActivityWidget->activityType();
 
     KVBox *page = new KVBox();
     pageItemGeneral = new KPageWidgetItem( page, i18nc("general properties page", "General") );
@@ -130,17 +143,17 @@ void ActivityDialog::setupGeneralPage()
     pageItemGeneral->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_General) );
     addPage( pageItemGeneral );
 
-    m_GenPageWidgets.generalGB = new Q3GroupBox( i18n( "Properties"), (QWidget *)page );
+    m_GenPageWidgets.generalGB = new QGroupBox( i18n( "Properties"), (QWidget *)page );
 
     QGridLayout * generalLayout = new QGridLayout( m_GenPageWidgets.generalGB );
-    generalLayout -> setSpacing( spacingHint() );
-    generalLayout -> setMargin(  fontMetrics().height()  );
+    generalLayout->setSpacing( spacingHint() );
+    generalLayout->setMargin(  fontMetrics().height()  );
 
     QString actType ( types[ (int)type ] );
     Dialog_Utils::makeLabeledEditField( m_GenPageWidgets.generalGB, generalLayout, 0,
                                     m_GenPageWidgets.typeL, i18n("Activity type:"),
                                     m_GenPageWidgets.typeLE, actType );
-    m_GenPageWidgets.typeLE -> setEnabled( false );
+    m_GenPageWidgets.typeLE->setEnabled( false );
 
     Dialog_Utils::makeLabeledEditField( m_GenPageWidgets.generalGB, generalLayout, 1,
                                     m_GenPageWidgets.nameL, i18n("Activity name:"),
@@ -159,13 +172,13 @@ void ActivityDialog::setupGeneralPage()
     m_GenPageWidgets.postLE->hide();
 
     m_GenPageWidgets.NormalRB = new QRadioButton( i18n("&Normal activity"),(QWidget *)page);
-    generalLayout -> addWidget( m_GenPageWidgets.NormalRB );
+    generalLayout->addWidget( m_GenPageWidgets.NormalRB );
 
     m_GenPageWidgets.InvokRB = new QRadioButton( i18n("&Invoke action "),(QWidget *)page);
-    generalLayout -> addWidget( m_GenPageWidgets.InvokRB );
+    generalLayout->addWidget( m_GenPageWidgets.InvokRB );
 
     m_GenPageWidgets.ParamRB = new QRadioButton( i18n("&Parameter activity node"),(QWidget *)page);
-    generalLayout -> addWidget( m_GenPageWidgets.ParamRB );
+    generalLayout->addWidget( m_GenPageWidgets.ParamRB );
 
     if (type == ActivityWidget::Param)
     {
@@ -176,7 +189,7 @@ void ActivityDialog::setupGeneralPage()
     connect(m_GenPageWidgets.NormalRB,SIGNAL(clicked()),this,SLOT(slotHideActivityParameter()));
     connect(m_GenPageWidgets.InvokRB,SIGNAL(clicked()),this,SLOT(slotHideActivityParameter()));
 
-    ActivityWidget::ActivityType newType = m_pActivityWidget -> getActivityType() ;
+    ActivityWidget::ActivityType newType = m_pActivityWidget->activityType() ;
 
     m_GenPageWidgets.NormalRB->setChecked(newType == ActivityWidget::Normal);
 
@@ -184,23 +197,26 @@ void ActivityDialog::setupGeneralPage()
 
     m_GenPageWidgets.ParamRB->setChecked (newType == ActivityWidget::Param);
 
-    m_GenPageWidgets.docGB = new Q3GroupBox( i18n( "Documentation"), (QWidget *)page );
+    m_GenPageWidgets.docGB = new QGroupBox( i18n( "Documentation"), (QWidget *)page );
 
     QHBoxLayout * docLayout = new QHBoxLayout( m_GenPageWidgets.docGB );
-    docLayout -> setSpacing( spacingHint() );
-    docLayout -> setMargin(  fontMetrics().height()  );
+    docLayout->setSpacing( spacingHint() );
+    docLayout->setMargin(  fontMetrics().height()  );
 
-    m_GenPageWidgets.docMLE = new Q3MultiLineEdit( m_GenPageWidgets.docGB );
-    m_GenPageWidgets.docMLE -> setText( m_pActivityWidget -> getDoc() );
-    docLayout -> addWidget( m_GenPageWidgets.docMLE );
+    m_GenPageWidgets.docTE = new KTextEdit( m_GenPageWidgets.docGB );
+    m_GenPageWidgets.docTE->setText( m_pActivityWidget->documentation() );
+    docLayout->addWidget( m_GenPageWidgets.docTE );
 
     if ( type != ActivityWidget::Normal && type != ActivityWidget::Invok && type != ActivityWidget::Param) {
-        m_GenPageWidgets.nameLE -> setEnabled( false );
-        m_GenPageWidgets.nameLE -> setText( "" );
+        m_GenPageWidgets.nameLE->setEnabled( false );
+        m_GenPageWidgets.nameLE->setText( "" );
     } else
-        m_GenPageWidgets.nameLE -> setText( m_pActivityWidget -> getName() );
+        m_GenPageWidgets.nameLE->setText( m_pActivityWidget->name() );
 }
 
+/**
+ *   Sets up the font selection page.
+ */
 void ActivityDialog::setupFontPage()
 {
     KVBox *page = new KVBox();
@@ -209,25 +225,29 @@ void ActivityDialog::setupFontPage()
     pageItemFont->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_Font) );
     addPage( pageItemFont );
     m_pChooser = new KFontChooser( (QWidget*)page, false, QStringList(), false);
-    m_pChooser -> setFont( m_pActivityWidget -> getFont() );
+    m_pChooser->setFont( m_pActivityWidget->font() );
 }
 
+/**
+ *   Show the Activity Parameter entry text.
+ */
 void ActivityDialog::showParameterActivity()
 {
     m_GenPageWidgets.preL->show();
     m_GenPageWidgets.preLE->show();
     m_GenPageWidgets.postL->show();
     m_GenPageWidgets.postLE->show();
-    if (m_pActivityWidget->getPostText() != NULL)
-    {
-        m_GenPageWidgets.postLE->setText(m_pActivityWidget->getPostText());
+    if (!m_pActivityWidget->postconditionText().isEmpty()) {
+        m_GenPageWidgets.postLE->setText(m_pActivityWidget->postconditionText());
     }
-    if (m_pActivityWidget->getPreText() != NULL)
-    {
-        m_GenPageWidgets.preLE->setText(m_pActivityWidget->getPreText());
+    if (!m_pActivityWidget->preconditionText().isEmpty()) {
+        m_GenPageWidgets.preLE->setText(m_pActivityWidget->preconditionText());
     }
 }
 
+/**
+ *   Sets up the color page.
+ */
 void ActivityDialog::setupColorPage()
 {
     QFrame *colorPage = new QFrame();
@@ -237,7 +257,7 @@ void ActivityDialog::setupColorPage()
     addPage( pageItemColor );
     QHBoxLayout * m_pColorLayout = new QHBoxLayout(colorPage);
     m_pColorPage = new UMLWidgetColorPage( colorPage, m_pActivityWidget );
-    m_pColorLayout -> addWidget(m_pColorPage);
+    m_pColorLayout->addWidget(m_pColorPage);
 }
 
 #include "activitydialog.moc"
