@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2003-2008                                                *
+ *  copyright (C) 2003-2009                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -16,23 +16,39 @@
 #include "enum.h"
 #include "entity.h"
 #include "attribute.h"
+#include "listpopupmenu.h"
 #include "operation.h"
 #include "template.h"
 #include "enumliteral.h"
 #include "entityattribute.h"
 #include "object_factory.h"
 
+#include <karrowbutton.h>
 #include <kdebug.h>
 #include <kdialogbuttonbox.h>
 #include <klocale.h>
 #include <ktabwidget.h>
+#include <ktextedit.h>
 
 #include <QtGui/QApplication>
+#include <QtGui/QGroupBox>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QListWidget>
+#include <QtGui/QPushButton>
+#include <QtGui/QVBoxLayout>
 
 using namespace Uml;
 
+/**
+ *  Sets up the ClassifierListPage.
+ *  @param parent      The parent to the ClassAttPage.
+ *  @param classifier  The Concept to display the properties of.
+ *  @param doc         The UMLDoc document
+ *  @param type        The type of listItem this handles
+ */
 ClassifierListPage::ClassifierListPage(QWidget* parent, UMLClassifier* classifier,
-                                       UMLDoc* doc, Uml::Object_Type type) : QWidget(parent)
+                                       UMLDoc* doc, Uml::Object_Type type)
+  : QWidget(parent)
 {
     m_itemType = type;
     m_bSigWaiting = false;
@@ -43,6 +59,16 @@ ClassifierListPage::ClassifierListPage(QWidget* parent, UMLClassifier* classifie
     setupPage();
 }
 
+/**
+ *  Standard destructor.
+ */
+ClassifierListPage::~ClassifierListPage()
+{
+}
+
+/**
+ * Sets up the page.
+ */
 void ClassifierListPage::setupPage()
 {
     int margin = fontMetrics().height();
@@ -75,6 +101,10 @@ void ClassifierListPage::setupPage()
     connect(m_pBottomArrowB, SIGNAL( clicked() ), this, SLOT( slotBottomClicked() ) );
 }
 
+/**
+ * Sets up the list group.
+ * @param margin  The margin of the group.
+ */
 void ClassifierListPage::setupListGroup(int margin)
 {
     QString typeName;
@@ -129,6 +159,10 @@ void ClassifierListPage::setupListGroup(int margin)
     setupActionButtons(newItemType, listVBoxLayout);
 }
 
+/**
+ * Sets up the move up/down buttons.
+ * @param parentLayout  The parent layout to which this group belongs.
+ */
 void ClassifierListPage::setupMoveButtons(QHBoxLayout* parentLayout)
 {
     QVBoxLayout* buttonLayout = new QVBoxLayout();
@@ -155,6 +189,11 @@ void ClassifierListPage::setupMoveButtons(QHBoxLayout* parentLayout)
     buttonLayout->addWidget( m_pBottomArrowB );
 }
 
+/**
+ * Sets up the action buttons.
+ * @param itemType      The item type.
+ * @param parentLayout  The parent layout to which this group belongs.
+ */
 void ClassifierListPage::setupActionButtons(const QString& itemType, QVBoxLayout* parentLayout)
 {
     KDialogButtonBox* buttonBox = new KDialogButtonBox(m_pItemListGB);
@@ -166,6 +205,10 @@ void ClassifierListPage::setupActionButtons(const QString& itemType, QVBoxLayout
     parentLayout->addWidget(buttonBox);
 }
 
+/**
+ * Sets up the documentation group.
+ * @param margin  The margin of the group.
+ */
 void ClassifierListPage::setupDocumentationGroup(int margin)
 {
     m_pDocGB = new QGroupBox(i18n("Documentation"), this);
@@ -186,6 +229,9 @@ void ClassifierListPage::setupDocumentationGroup(int margin)
     }
 }
 
+/**
+ * Loads the Item List Box.
+ */
 void ClassifierListPage::reloadItemListBox()
 {
     UMLClassifierListItemList itemList(getItemList());
@@ -201,10 +247,10 @@ void ClassifierListPage::reloadItemListBox()
     }
 }
 
-ClassifierListPage::~ClassifierListPage()
-{
-}
-
+/**
+ * Set the state of the widgets on the page with the given value.
+ * @param  state   The state to set the widgets as.
+ */
 void ClassifierListPage::enableWidgets(bool state)
 {
     m_pDocTE->setEnabled( state );
@@ -257,6 +303,10 @@ void ClassifierListPage::enableWidgets(bool state)
     m_pPropertiesButton->setEnabled(true);
 }
 
+/**
+ * Called whenever the list item needs to be activated
+ * calls enableWidgets().
+ */
 void ClassifierListPage::slotActivateItem(QListWidgetItem* item)
 {
     //if not first time an item is highlighted
@@ -306,6 +356,10 @@ void ClassifierListPage::slotActivateItem(QListWidgetItem* item)
     }
 }
 
+/**
+ *  Will move information from the dialog into the object.
+ *  Call when the ok or apply button is pressed.
+ */
 void ClassifierListPage::updateObject()
 {
     saveCurrentItemDocumentation();
@@ -323,16 +377,26 @@ void ClassifierListPage::slotListItemCreated(UMLObject* object)
         return;
     }
 
-    int index = calculateNewIndex(listItem->getBaseType());
-
-    m_pItemListLB->insertItem(index, listItem->toString(Uml::st_SigNoVis));
+    QString itemStr = listItem->toString(Uml::st_SigNoVis);
+    // already in list?
+    QList<QListWidgetItem*> foundItems = m_pItemListLB->findItems(itemStr, Qt::MatchExactly);
+    int index = -1;
+    if (foundItems.empty()) {
+        index = m_pItemListLB->count();
+        m_pItemListLB->insertItem(index, itemStr);
+    }
+    else {
+        index = m_pItemListLB->row(foundItems[0]);
+    }
     m_bSigWaiting = false;
 
     // now select the new item, so that the user can go on adding doc or calling
     // the property dialog
-    m_pItemListLB->setCurrentRow(index);
-    slotActivateItem(m_pItemListLB->item(index));
-    connect( object, SIGNAL( modified() ), this, SLOT( slotListItemModified() ) );
+    if (index > -1) {
+        m_pItemListLB->setCurrentItem(m_pItemListLB->item(index));
+        slotActivateItem(m_pItemListLB->item(index));
+        connect( object, SIGNAL( modified() ), this, SLOT( slotListItemModified() ) );
+    }
 }
 
 void ClassifierListPage::slotListItemModified()
@@ -349,6 +413,9 @@ void ClassifierListPage::slotListItemModified()
     }
 }
 
+/**
+ * Hide menu and free all its resources.
+ */
 void ClassifierListPage::deleteMenu()
 {
     if (m_pMenu) {
@@ -398,6 +465,9 @@ void ClassifierListPage::slotRightButtonPressed(const QPoint& pos)
     connect(m_pMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotPopupMenuSel(QAction*)));
 }
 
+/**
+ * Called when an item is selected in a right click menu.
+ */
 void ClassifierListPage::slotPopupMenuSel(QAction* action)
 {
     ListPopupMenu::Menu_Type id = m_pMenu->getMenuType(action);
@@ -438,6 +508,10 @@ void ClassifierListPage::slotPopupMenuSel(QAction* action)
     }
 }
 
+/**
+ * Utility for debugging, prints the current item list.
+ * Only effective if VERBOSE_DEBUGGING is defined.
+ */
 void ClassifierListPage::printItemList(const QString &prologue)
 {
 #ifdef VERBOSE_DEBUGGING
@@ -454,6 +528,9 @@ void ClassifierListPage::printItemList(const QString &prologue)
 #endif
 }
 
+/**
+ * Moves selected attribute to the top of the list.
+ */
 void ClassifierListPage::slotTopClicked()
 {
     int count = m_pItemListLB->count();
@@ -485,6 +562,9 @@ void ClassifierListPage::slotTopClicked()
     slotActivateItem(item);
 }
 
+/**
+ * Moves selected attribute up in list.
+ */
 void ClassifierListPage::slotUpClicked()
 {
     int count = m_pItemListLB->count();
@@ -519,6 +599,9 @@ void ClassifierListPage::slotUpClicked()
     slotActivateItem(item);
 }
 
+/**
+ * Moved selected attribute down in list.
+ */
 void ClassifierListPage::slotDownClicked()
 {
     int count = m_pItemListLB->count();
@@ -552,6 +635,9 @@ void ClassifierListPage::slotDownClicked()
     slotActivateItem(item);
 }
 
+/**
+ * Moved selected attribute to the bottom of the list.
+ */
 void ClassifierListPage::slotBottomClicked()
 {
     int count = m_pItemListLB->count();
@@ -583,6 +669,9 @@ void ClassifierListPage::slotBottomClicked()
     slotActivateItem(item);
 }
 
+/**
+ * Shows properties dialog for the attribute clicked on.
+ */
 void ClassifierListPage::slotDoubleClick( QListWidgetItem* item )
 {
     if ( !item ) {
@@ -601,30 +690,40 @@ void ClassifierListPage::slotDoubleClick( QListWidgetItem* item )
     }
 }
 
+/**
+ * Removes currently seleted attribute.
+ */
 void ClassifierListPage::slotDelete()
 {
     int currentItemIndex = m_pItemListLB->currentRow();
 
-    // index is -1 . Quit
-    if ( currentItemIndex==-1 ) {
-        return;
-    }
+    if ( currentItemIndex > -1 ) {
 
-    UMLClassifierListItem* selectedItem = getItemList().at( currentItemIndex );
-    //should really wait for signal back
-    //but really shouldn't matter
-    m_pDoc->removeUMLObject(selectedItem);
-    m_pItemListLB->takeItem( m_pItemListLB->currentRow());
-    m_pOldListItem = 0;
-    slotActivateItem(NULL);
+        // do this first
+        delete m_pItemListLB->takeItem(currentItemIndex);
+
+        UMLClassifierListItem* selectedItem = getItemList().at(currentItemIndex);
+        //should really wait for signal back
+        //but really shouldn't matter
+        m_pDoc->removeUMLObject(selectedItem);
+        m_pOldListItem = 0;
+
+        slotActivateItem(NULL);
+    }
 }
 
+/**
+ * Shows properties dialog for currently selected attribute.
+ */
 void ClassifierListPage::slotProperties()
 {
     saveCurrentItemDocumentation();
     slotDoubleClick( m_pItemListLB->currentItem() );
 }
 
+/**
+ * Shows dialog for new attribute.
+ */
 void ClassifierListPage::slotNewListItem()
 {
     saveCurrentItemDocumentation();
@@ -635,6 +734,9 @@ void ClassifierListPage::slotNewListItem()
     }
 }
 
+/**
+ * Saves the documentation for the currently selected item.
+ */
 void ClassifierListPage::saveCurrentItemDocumentation()
 {
     int currentItemIndex = m_pItemListLB->currentRow();
@@ -653,11 +755,21 @@ void ClassifierListPage::saveCurrentItemDocumentation()
     }
 }
 
+/**
+ * Get classifier list items.
+ */
 UMLClassifierListItemList ClassifierListPage::getItemList()
 {
     return m_pClassifier->getFilteredList(m_itemType);
 }
 
+/**
+ * Attempts to add classifier to the appropriate list.
+ * @param classifier   Pointer to the classifier to add.
+ * @param position     Index at which to insert into the list.
+ * @return             true if the classifier could be added
+ *
+ */
 bool ClassifierListPage::addClassifier(UMLClassifierListItem* listitem, int position)
 {
     switch (m_itemType) {
@@ -696,6 +808,19 @@ bool ClassifierListPage::addClassifier(UMLClassifierListItem* listitem, int posi
     return false;
 }
 
+/**
+ * Take a classifier's subordinate item.
+ * Ownership of the classifier list item is transferred to the caller.
+ * @param listitem        UMLClassifierListItem to take.
+ * @param seekPeerBefore  True if a peer index should be sought which
+ *                        is smaller than the current listitem's index.
+ * @param peerIndex       Return value: Index in the UMLClassifier's
+ *                        item list at which a peer item, i.e. another
+ *                        UMLClassifierListItem of the same type as
+ *                        listItem, is found.  If no such item exists
+ *                        then return -1.
+ * @return                True for success.
+ */
 bool ClassifierListPage::takeItem(UMLClassifierListItem* listItem,
                                   bool seekPeerBefore, int &peerIndex)
 {
@@ -725,12 +850,10 @@ bool ClassifierListPage::takeItem(UMLClassifierListItem* listItem,
     return true;
 }
 
-int ClassifierListPage::calculateNewIndex(Uml::Object_Type ot)
-{
-    Q_UNUSED(ot);
-    return m_pItemListLB->count();
-}
-
+/**
+ * Sets the visibility of the arrow buttons.
+ * @param hide true hides the arrow buttons
+ */
 void ClassifierListPage::hideArrowButtons(bool hide)
 {
     // if hide is true, we have to make state = false
