@@ -63,6 +63,9 @@ void UMLViewDialog::slotApply()
     applyPage( currentPage() );
 }
 
+/**
+ * Sets up the dialog pages.
+ */
 void UMLViewDialog::setupPages()
 {
     setupDiagramPropertiesPage();
@@ -71,6 +74,9 @@ void UMLViewDialog::setupPages()
     setupClassPage();
 }
 
+/**
+ * Sets up the general Diagram Properties Page
+ */
 void UMLViewDialog::setupDiagramPropertiesPage()
 {
     KVBox *page = new KVBox();
@@ -95,6 +101,9 @@ void UMLViewDialog::setupDiagramPropertiesPage()
     m_diagramProperties->ui_documentation->setText(m_pView->getDoc());
 }
 
+/**
+ * Sets up the Class page
+ */
 void UMLViewDialog::setupClassPage()
 {
     if ( m_pView -> getType() != Uml::dt_Class ) {
@@ -108,9 +117,12 @@ void UMLViewDialog::setupClassPage()
 
     QHBoxLayout * pOptionsLayout = new QHBoxLayout( newPage );
     m_pOptionsPage = new ClassOptionsPage( newPage, &m_options );
-    pOptionsLayout -> addWidget( m_pOptionsPage );
+    pOptionsLayout->addWidget( m_pOptionsPage );
 }
 
+/**
+ * Sets up the color page.
+ */
 void UMLViewDialog::setupColorPage()
 {
     QFrame * colorPage = new QFrame();
@@ -121,9 +133,12 @@ void UMLViewDialog::setupColorPage()
 
     QHBoxLayout * m_pColorLayout = new QHBoxLayout(colorPage);
     m_pColorPage = new UMLWidgetColorPage( colorPage, &m_options );
-    m_pColorLayout -> addWidget(m_pColorPage);
+    m_pColorLayout->addWidget(m_pColorPage);
 }
 
+/**
+ *   Sets up font page.
+ */
 void UMLViewDialog::setupFontPage()
 {
     KVBox *page = new KVBox();
@@ -136,13 +151,16 @@ void UMLViewDialog::setupFontPage()
     m_pChooser->setFont( m_pView->getOptionState().uiState.font );
 }
 
-void UMLViewDialog::applyPage( KPageWidgetItem*item )
+/**
+ * Applies the properties of the given page.
+ */
+void UMLViewDialog::applyPage( KPageWidgetItem *item )
 {
     if ( item == m_pageGeneralItem )
     {
         checkName();
         m_pView->setZoom( m_diagramProperties->ui_zoom->value() );
-        m_pView->setDoc( m_diagramProperties->ui_documentation->text() );
+        m_pView->setDoc( m_diagramProperties->ui_documentation->toPlainText() );
         m_pView->setSnapX( m_diagramProperties->ui_gridSpaceX->value() );
         m_pView->setSnapY( m_diagramProperties->ui_gridSpaceY->value() );
         m_pView->setLineWidth( m_diagramProperties->ui_lineWidth->value() );
@@ -180,6 +198,9 @@ void UMLViewDialog::applyPage( KPageWidgetItem*item )
     }
 }
 
+/**
+ * Checks whether the name is unique and sets it if it is.
+ */
 void UMLViewDialog::checkName()
 {
     QString name = m_diagramProperties->ui_diagramName-> text();
