@@ -1,15 +1,15 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2007                                               *
+ *   copyright (C) 2002-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include <unistd.h>
+#include <stdio.h>
 
 // kde includes
 #include <kaboutdata.h>
@@ -26,28 +26,24 @@
 #include "version.h"
 #include "umldoc.h"
 #include "cmdlineexportallviewsevent.h"
+#include "umlviewimageexportermodel.h"
 #include "umbrellosettings.h"
 
-
 /**
  * Description for this application
  */
 static const char description[] =
     I18N_NOOP("Umbrello UML Modeller");
 
-
-/**
- * @todo Add options to use the documentation generators from command line.
- */
 /**
  * Determines if the application GUI should be shown based on command line arguments.
+ * @todo Add options to use the documentation generators from command line.
  *
  * @param args The command line arguments given.
  * @return True if the GUI should be shown, false otherwise.
  */
 bool getShowGUI(KCmdLineArgs *args);
 
-
 /**
  * Initializes the document used by the application.
  * If a file was specified in command line arguments, opens that file. Else, it
@@ -58,7 +54,6 @@ bool getShowGUI(KCmdLineArgs *args);
  */
 void initDocument(KCmdLineArgs *args);
 
-
 /**
  * Export all the views in the document using the command line args set by the user.
  * Errors that occurred while exporting, if any, are shown using uError().
@@ -81,6 +76,7 @@ int main(int argc, char *argv[])
     KCmdLineOptions options;
     options.add("+[File]", ki18n("File to open"));
     options.add("export <extension>", ki18n("export diagrams to extension and exit"));
+    options.add("export-formats", ki18n("list available export extensions"));
     options.add("directory <url>", ki18n("the local directory to save the exported diagrams in"), I18N_NOOP("the directory of the file"));
     options.add("use-folders", ki18n("keep the tree structure used to store the views in the document in the target directory"));
     KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
@@ -101,6 +97,11 @@ int main(int argc, char *argv[])
 
         initDocument(args);
 
+        if (args->isSet("export-formats")) {
+            foreach(const QString& type, UMLViewImageExporterModel::supportedImageTypes())
+                fprintf(stderr, "%s\n", qPrintable(type));
+            return 0;
+        }
         // export option
         QStringList exportOpt = args->getOptionList("export");
         if (exportOpt.size() > 0) {
@@ -118,10 +119,9 @@ bool getShowGUI(KCmdLineArgs *args)
     return true;
 }
 
-
 void initDocument(KCmdLineArgs *args)
 {
-    if ( args -> count() ) {
+    if ( args->count() ) {
         UMLApp::app()->openDocumentFile( args->url( 0 ) );
     } else {
         bool last = UmbrelloSettings::loadlast();
@@ -134,7 +134,6 @@ void initDocument(KCmdLineArgs *args)
     }
 }
 
-
 void exportAllViews(KCmdLineArgs *args, const QStringList &exportOpt)
 {
     QString extension(exportOpt.last());
@@ -154,7 +153,7 @@ void exportAllViews(KCmdLineArgs *args, const QStringList &exportOpt)
 
     uDebug() << "directory: " << directory.prettyUrl();
 
-    // the event is posted so when the QT loop begins it's processed. UMLApp process this event executing
+    // the event is posted so when the Qt loop begins it's processed. UMLApp process this event executing
     // the method it provides for exporting the views. Once all the views were exported, a quit event
     // is sent and the app finishes without user interaction
     kapp->postEvent(UMLApp::app(), new CmdLineExportAllViewsEvent(extension, directory, useFolders));
